INN commit: branches/2.4/scripts (innreport_inn.pm)

INN Commit Russ_Allbery at isc.org
Tue Jun 24 06:48:20 UTC 2008


    Date: Monday, June 23, 2008 @ 23:48:19
  Author: iulius
Revision: 7919

Suppress a few other nnrpd and controlchan notices in innreport.

Modified:
  branches/2.4/scripts/innreport_inn.pm

------------------+
 innreport_inn.pm |   23 +++++++++++++++++------
 1 file changed, 17 insertions(+), 6 deletions(-)

Modified: innreport_inn.pm
===================================================================
--- innreport_inn.pm	2008-06-24 06:47:46 UTC (rev 7918)
+++ innreport_inn.pm	2008-06-24 06:48:19 UTC (rev 7919)
@@ -1329,7 +1329,10 @@
       $nnrpd_no_permission{$cust}++;
       return 1;
     }
-    return 1 if $left =~ /^\S+ auth: program error: ckpasswd: user .+ unknown$/o;
+    # Authentication failure
+    # User not known to the underlying authentication module
+    return 1 if $left =~ / ckpasswd: pam_authenticate failed: /o;
+    return 1 if $left =~ / ckpasswd: user .+ unknown$/o;
     # authinfo
     if ($left =~ /\S+ user (\S+)$/o) {
       my $user = $1;
@@ -1427,6 +1430,8 @@
       $nnrpd_reset_peer{$cust}++;
       return 1;
     }
+    # can't read: Network is unreachable
+    return 1 if $left =~ /(\S+) can\'t read: Network is unreachable$/o;
     # gethostbyaddr: xxx.yyy.zzz != a.b.c.d
     if ($left =~ /^gethostbyaddr: (.*)$/o) {
       my $msg = $1;
@@ -1445,8 +1450,10 @@
       $nnrpd_gethostbyaddr{"? (can't getpeername)"}++;
       return 1;
     }
+    # can't getsockname
+    return 1 if $left =~ /^\S+ can\'t getsockname$/o;
     # reverse lookup failed
-    return 1 if $left =~ /^\? reverse lookup for \S+ failed: Name or service not known -- using IP address for access$/o;
+    return 1 if $left =~ /^\? reverse lookup for \S+ failed: .* -- using IP address for access$/o;
     # profile timer
     # ME time X nnnn X(X) [...]
     # The exact timers change from various versions of INN, so try to deal
@@ -1480,10 +1487,12 @@
     return 1 if $left =~ /^\S+ newnews /o;
     # cant fopen (ignored too)
     return 1 if $left =~ /^\S+ cant fopen /o;
-    # cant read No route to host
-    return 1 if $left =~ /cant read No route to host/o;
-    # cant read Broken pipe
-    return 1 if $left =~ /cant read Broken pipe/o;
+    # can't read: No route to host
+    return 1 if $left =~ /can\'t read: No route to host/o;
+    # can't read: Broken pipe
+    return 1 if $left =~ /can\'t read: Broken pipe/o;
+    # eof in post
+    return 1 if $left =~ /^\S+ eof in post$/o;
     # ioctl: ...
     return 1 if $left =~ /^ioctl: /o;
     # other stats
@@ -1735,6 +1744,8 @@
       $controlchan_doit{$email}++ if $action eq 'doit';
       return 1;
     }
+    # checkgroups processed (no change or not)
+    return 1 if $left =~ /^checkgroups by \S+ processed/o;
   }
 
   ###########



More information about the inn-committers mailing list